@@ -308,7 +308,13 @@ class SlackBot(StreamHandler):
 
         # retrieve target user ID
         if user_member_ids is not None:
-            target_users = [user_member_ids]
+            if type(user_member_ids) is str:
+                target_users = [user_member_ids]
+            elif type(user_member_ids) in [tuple, list]:
+                target_users = user_member_ids
+            else:
+                raise TypeError(
+                    f'an unsupported type was provided for user_member_ids. A string or iterable of strings is expected.')
         elif self.target_users is not None:
             target_users = self.target_users
         else:
@@ -353,7 +359,12 @@ class SlackBot(StreamHandler):
         """
         # retrieve target user ID
         if user_member_ids is not None:
-            target_users = [user_member_ids]
+            if type(user_member_ids) is str:
+                target_users = [user_member_ids]
+            elif type(user_member_ids) in [tuple, list]:
+                target_users = user_member_ids
+            else:
+                raise TypeError(f'an unsupported type was provided for user_member_ids. A string or iterable of strings is expected.')
         elif self.target_users is not None:
             target_users = self.target_users
         else:
