@@ -120,11 +120,13 @@ class RTMControlManager(RTMSlackBot, ControlManager):
     def help_query(self):
         self._help_query = return_empty
 
-    def catch_and_match(self, pattern: Pattern, **payload) -> bool:
+    def catch_and_match(self, pattern: Pattern, full_match: bool = True, **payload) -> bool:
         """
         Attempts to match a regex pattern to the message provided
 
         :param pattern: regex pattern to compare against the text
+        :param full_match:  if True, then the payload is text has to re.fullmatch the pattern to return True,
+            else, as long as the pattern is found somewhere in the text (re.search), then the return value will be True
         :param payload: RTM payload
         :return: match truth
         """
@@ -133,9 +135,14 @@ class RTMControlManager(RTMSlackBot, ControlManager):
             return False
         message = payload['data']
         text = message.get('text')
-        if pattern.search(text) is not None:
-            logger.debug(f'{pattern} catch triggered by "{text}"')
-            return True
+        if full_match:
+            if pattern.fullmatch(text) is not None:
+                logger.debug(f'{pattern} catch triggered by "{text}"')
+                return True
+        else:
+            if pattern.search(text) is not None:
+                logger.debug(f'{pattern} catch triggered by "{text}"')
+                return True
         return False
 
     def start_catch(self, **payload):
@@ -148,10 +155,6 @@ class RTMControlManager(RTMSlackBot, ControlManager):
                     )
                     # assumes non-blocking
                     self.start_action()
-                else:
-                    self.post_slack_message(
-                        'Sorry, there is no start action defined :disappointed:'
-                    )
 
     def pause_catch(self, **payload):
         """catches pause calls and executes the pause action"""
@@ -163,10 +166,6 @@ class RTMControlManager(RTMSlackBot, ControlManager):
                     )
                     # assumes non-blocking
                     self.pause_action()
-                else:
-                    self.post_slack_message(
-                        'Sorry, there is no pause action defined :disappointed:'
-                    )
 
     def resume_catch(self, **payload):
         """catches resume calls and execute the resume action"""
@@ -178,10 +177,6 @@ class RTMControlManager(RTMSlackBot, ControlManager):
                     )
                     # assumes non-blocking
                     self.resume_action()
-                else:
-                    self.post_slack_message(
-                        'Sorry, there is no resume action defined :disappointed:'
-                    )
 
     def stop_catch(self, **payload):
         """catches stop calls and executes the stop action"""
@@ -193,10 +188,6 @@ class RTMControlManager(RTMSlackBot, ControlManager):
                     )
                     # assumes non-blocking
                     self.stop_action()
-                else:
-                    self.post_slack_message(
-                        'Sorry, there is no stop action defined :disappointed:'
-                    )
 
     def status_catch(self, **payload):
         """catches and posts the status query string"""
@@ -204,11 +195,7 @@ class RTMControlManager(RTMSlackBot, ControlManager):
             with WebClientOverride(self, payload['web_client']):
                 if self.status_query is not return_empty:
                     self.post_slack_message(
-                        f"Here's the current status: `{self.status_query()}`"
-                    )
-                else:
-                    self.post_slack_message(
-                        'Sorry, there is no status query defined :disappointed:'
+                        f"Here's the current status:\n`{self.status_query()}`"
                     )
 
     def help_catch(self, **payload):
@@ -221,9 +208,5 @@ class RTMControlManager(RTMSlackBot, ControlManager):
                 #   - add to help string
                 if self.help_query is not return_empty:
                     self.post_slack_message(
-                        f"Here's how to use the Slack interface: `{self.help_query()}`"
-                    )
-                else:
-                    self.post_slack_message(
-                        'Sorry, there is no help query defined :disappointed:'
+                        f"Here's how to use the Slack interface:\n`{self.help_query()}`"
                     )
